@@ -48,7 +48,11 @@ class Q_DECL_HIDDEN LoadFeedListCommand::Private
 {
     LoadFeedListCommand *const q;
 public:
-    explicit Private(LoadFeedListCommand *qq) : q(qq), storage(0) {}
+    explicit Private(LoadFeedListCommand *qq) : q(qq)
+        , storage(nullptr)
+    {
+    }
+
     void handleDocument(const QDomDocument &doc);
     QString createBackup(const QString &path, bool *ok);
     void emitResult(const QSharedPointer<FeedList> &list);
@@ -71,12 +75,12 @@ void LoadFeedListCommand::Private::handleDocument(const QDomDocument &doc)
     if (!feedList->readFromOpml(doc)) {
         bool backupCreated;
         const QString backupFile = createBackup(fileName, &backupCreated);
-        const QString msg =
-            backupCreated ?
-            i18n("<qt>The standard feed list is corrupted (invalid OPML). "
-                 "A backup was created:<p><b>%1</b></p></qt>", backupFile) :
-            i18n("<qt>The standard feed list is corrupted (invalid OPML). "
-                 "Could not create a backup.</qt>");
+        const QString msg
+            = backupCreated
+              ? i18n("<qt>The standard feed list is corrupted (invalid OPML). "
+                     "A backup was created:<p><b>%1</b></p></qt>", backupFile)
+              : i18n("<qt>The standard feed list is corrupted (invalid OPML). "
+                     "Could not create a backup.</qt>");
 
         QPointer<QObject> that(q);
         KMessageBox::error(q->parentWidget(), msg, i18n("OPML Parsing Error"));
@@ -101,7 +105,8 @@ QString LoadFeedListCommand::Private::createBackup(const QString &path, bool *ok
     return backup;
 }
 
-LoadFeedListCommand::LoadFeedListCommand(QObject *parent) : Command(parent), d(new Private(this))
+LoadFeedListCommand::LoadFeedListCommand(QObject *parent) : Command(parent)
+    , d(new Private(this))
 {
 }
 
@@ -114,6 +119,7 @@ void LoadFeedListCommand::setFileName(const QString &fileName)
 {
     d->fileName = fileName;
 }
+
 void LoadFeedListCommand::setDefaultFeedList(const QDomDocument &doc)
 {
     d->defaultFeedList = doc;
@@ -131,7 +137,6 @@ void LoadFeedListCommand::doStart()
 
 void LoadFeedListCommand::doAbort()
 {
-
 }
 
 void LoadFeedListCommand::Private::doLoad()
@@ -172,19 +177,19 @@ void LoadFeedListCommand::Private::doLoad()
         bool backupCreated = false;
         const QString backupFile = createBackup(fileName, &backupCreated);
         const QString title = i18nc("error message window caption", "XML Parsing Error");
-        const QString details =
-            xi18n("<qt><p>XML parsing error in line %1, "
-                  "column %2 of %3:</p><p>%4</p></qt>",
-                  QString::number(errLine),
-                  QString::number(errCol),
-                  fileName,
-                  errMsg);
-        const QString msg =
-            backupCreated ?
-            i18n("<qt>The standard feed list is corrupted (invalid XML). "
-                 "A backup was created:<p><b>%1</b></p></qt>", backupFile) :
-            i18n("<qt>The standard feed list is corrupted (invalid XML). "
-                 "Could not create a backup.</qt>");
+        const QString details
+            = xi18n("<qt><p>XML parsing error in line %1, "
+                    "column %2 of %3:</p><p>%4</p></qt>",
+                    QString::number(errLine),
+                    QString::number(errCol),
+                    fileName,
+                    errMsg);
+        const QString msg
+            = backupCreated
+              ? i18n("<qt>The standard feed list is corrupted (invalid XML). "
+                     "A backup was created:<p><b>%1</b></p></qt>", backupFile)
+              : i18n("<qt>The standard feed list is corrupted (invalid XML). "
+                     "Could not create a backup.</qt>");
 
         QPointer<QObject> that(q);
 
