@@ -43,7 +43,7 @@
 #include "expireitemscommand.h"
 #include "importfeedlistcommand.h"
 #include "feed.h"
-#include "helper_p.h"
+
 #include "feedlist.h"
 #include "feedpropertiesdialog.h"
 #include "fetchqueue.h"
@@ -65,7 +65,6 @@
 #include "mainframe.h"
 #include <WebEngineViewer/ZoomActionMenu>
 #include "job/downloadarticlejob.h"
-#include <WebEngineViewer/LocalDataBaseManager>
 
 #include <QAction>
 #include <kfileitem.h>
@@ -107,16 +106,14 @@ MainWidget::~MainWidget()
 }
 
 MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionManager, const QString &name)
-    : QWidget(parent),
-      m_feedList(),
-      m_viewMode(NormalView),
-      m_actionManager(actionManager),
-      m_feedListManagementInterface(new FeedListManagementImpl)
+    : QWidget(parent)
+    , m_feedList()
+    , m_viewMode(NormalView)
+    , m_actionManager(actionManager)
+    , m_feedListManagementInterface(new FeedListManagementImpl)
 {
     setObjectName(name);
 
-    WebEngineViewer::LocalDataBaseManager::self()->initialize();
-
     FeedListManagementInterface::setInstance(m_feedListManagementInterface);
 
     m_actionManager->initMainWidget(this);
@@ -404,7 +401,7 @@ void MainWidget::sendArticle(bool attach)
         text = frame->url().toString().toLatin1();
         title = frame->title();
     } else { // nah, we're in articlelist..
-        const Article article =  m_selectionController->currentArticle();
+        const Article article = m_selectionController->currentArticle();
         if (!article.isNull()) {
             text = article.link().toDisplayString().toLatin1();
             title = Akregator::Utils::convertHtmlTags(article.title());
@@ -515,7 +512,7 @@ void MainWidget::addFeedToGroup(const QString &url, const QString &groupName)
     Folder *group = nullptr;
     for (TreeNode *const candidate : namedGroups) {
         if (candidate->isGroup()) {
-            group =  static_cast<Folder *>(candidate);
+            group = static_cast<Folder *>(candidate);
             break;
         }
     }
@@ -539,7 +536,7 @@ void MainWidget::slotNormalView()
     if (m_viewMode == CombinedView) {
         m_articleWidget->show();
 
-        const Article article =  m_selectionController->currentArticle();
+        const Article article = m_selectionController->currentArticle();
 
         if (!article.isNull()) {
             m_articleViewer->showArticle(article);
@@ -563,7 +560,7 @@ void MainWidget::slotWidescreenView()
     if (m_viewMode == CombinedView) {
         m_articleWidget->show();
 
-        Article article =  m_selectionController->currentArticle();
+        Article article = m_selectionController->currentArticle();
 
         if (!article.isNull()) {
             m_articleViewer->showArticle(article);
@@ -712,7 +709,6 @@ void MainWidget::slotFeedAdd()
         } else {
             group = m_selectionController->selectedSubscription()->parent();
         }
-
     }
 
     TreeNode *const lastChild = !group->children().isEmpty() ? group->children().last() : nullptr;
@@ -997,12 +993,11 @@ void MainWidget::openSelectedArticles(bool openInBackground)
             Kernel::self()->frameManager()->slotOpenUrlRequest(req);
         }
     }
-
 }
 
 void MainWidget::currentArticleInfo(QString &link, QString &title)
 {
-    const Article article =  m_selectionController->currentArticle();
+    const Article article = m_selectionController->currentArticle();
 
     if (article.isNull()) {
         return;
@@ -1020,7 +1015,7 @@ void MainWidget::updateQuickSearchLineText()
 
 void MainWidget::slotCopyLinkAddress()
 {
-    const Article article =  m_selectionController->currentArticle();
+    const Article article = m_selectionController->currentArticle();
 
     if (article.isNull()) {
         return;
@@ -1048,12 +1043,10 @@ void MainWidget::slotToggleShowQuickFilter()
             m_searchBar->show();
         }
     }
-
 }
 
 void MainWidget::slotArticleDelete()
 {
-
     if (m_viewMode == CombinedView) {
         return;
     }
@@ -1132,9 +1125,7 @@ void MainWidget::slotArticleToggleKeepFlag(bool)
     job->start();
 }
 
-namespace
-{
-
+namespace {
 void setArticleStatus(const QString &feedUrl, const QString &articleId, int status)
 {
     if (!feedUrl.isEmpty() && !articleId.isEmpty()) {
@@ -1160,7 +1151,6 @@ void setSelectedArticleStatus(const Akregator::AbstractSelectionController *cont
     }
     job->start();
 }
-
 }
 
 void MainWidget::slotSetSelectedArticleRead()
@@ -1180,7 +1170,7 @@ void MainWidget::slotSetSelectedArticleNew()
 
 void MainWidget::slotSetCurrentArticleReadDelayed()
 {
-    const Article article =  m_selectionController->currentArticle();
+    const Article article = m_selectionController->currentArticle();
 
     if (article.isNull()) {
         return;
@@ -1286,7 +1276,8 @@ void MainWidget::slotFocusQuickSearch()
 void MainWidget::slotArticleAction(Akregator::ArticleViewerWebEngine::ArticleAction type, const QString &articleId, const QString &feed)
 {
     switch (type) {
-    case ArticleViewerWebEngine::DeleteAction: {
+    case ArticleViewerWebEngine::DeleteAction:
+    {
         Akregator::ArticleDeleteJob *job = new Akregator::ArticleDeleteJob;
         const Akregator::ArticleId aid = { feed, articleId };
         job->appendArticleId(aid);
@@ -1300,7 +1291,8 @@ void MainWidget::slotArticleAction(Akregator::ArticleViewerWebEngine::ArticleAct
         ::setArticleStatus(feed, articleId, Akregator::Unread);
         break;
 
-    case ArticleViewerWebEngine::MarkAsImportant: {
+    case ArticleViewerWebEngine::MarkAsImportant:
+    {
         Akregator::ArticleModifyJob *job = new Akregator::ArticleModifyJob;
         const Akregator::Article article = m_feedList->findArticle(feed, articleId);
         const Akregator::ArticleId aid = { feed, articleId };
@@ -1308,18 +1300,20 @@ void MainWidget::slotArticleAction(Akregator::ArticleViewerWebEngine::ArticleAct
         job->start();
         break;
     }
-    case ArticleViewerWebEngine::SendUrlArticle: {
-        case ArticleViewerWebEngine::SendFileArticle:
-            const Article article =  m_feedList->findArticle(feed, articleId);
-            const QByteArray text = article.link().toDisplayString().toLatin1();
-            const QString title = Akregator::Utils::convertHtmlTags(article.title());
-            if (text.isEmpty()) {
-                return;
-            }
-            sendArticle(text, title, (type == ArticleViewerWebEngine::SendFileArticle));
-            break;
+    case ArticleViewerWebEngine::SendUrlArticle:
+    {
+    case ArticleViewerWebEngine::SendFileArticle:
+        const Article article = m_feedList->findArticle(feed, articleId);
+        const QByteArray text = article.link().toDisplayString().toLatin1();
+        const QString title = Akregator::Utils::convertHtmlTags(article.title());
+        if (text.isEmpty()) {
+            return;
         }
-    case ArticleViewerWebEngine::OpenInBackgroundTab: {
+        sendArticle(text, title, (type == ArticleViewerWebEngine::SendFileArticle));
+        break;
+    }
+    case ArticleViewerWebEngine::OpenInBackgroundTab:
+    {
         const Akregator::Article article = m_feedList->findArticle(feed, articleId);
         const QUrl url = article.link();
         if (url.isValid()) {
@@ -1330,7 +1324,8 @@ void MainWidget::slotArticleAction(Akregator::ArticleViewerWebEngine::ArticleAct
         }
         break;
     }
-    case ArticleViewerWebEngine::OpenInExternalBrowser: {
+    case ArticleViewerWebEngine::OpenInExternalBrowser:
+    {
         const Akregator::Article article = m_feedList->findArticle(feed, articleId);
         slotOpenArticleInBrowser(article);
         break;
