@@ -29,9 +29,7 @@
 #include <QAction>
 #include <QByteArray>
 
-namespace Akregator
-{
-
+namespace Akregator {
 class TreeNode;
 
 class SubscriptionListView : public QTreeView
@@ -46,10 +44,12 @@ public:
 
     void ensureNodeVisible(TreeNode *node);
 
-    //Q_DECL_OVERRIDE
-    void setModel(QAbstractItemModel *model) Q_DECL_OVERRIDE;
+    //override
+    void setModel(QAbstractItemModel *model) override;
 
-    void triggerUpdate() {}
+    void triggerUpdate()
+    {
+    }
 
     enum Column {
         TitleColumn = 0,
@@ -87,7 +87,6 @@ private Q_SLOTS:
 private:
     QByteArray m_headerState;
 };
-
 }
 
 #endif // AKREGATOR_SUBSCRIPTIONLISTVIEW_H
